package org.codehaus.plexus.interpolation;

/*
 * Copyright 2001-2008 Codehaus Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Tracks the most recent expression processed by this value source implementation.
 * This can be useful if the most recent expression is meant to modify the current
 * one.
 * @version $Id$
 */
public interface QueryEnabledValueSource
    extends ValueSource
{

    /**
     * @return the most recent expression processed by this value source, or null.
     */
    String getLastExpression();

}
